@@ -9,22 +9,57 @@ use Mojo::Util qw/slurp dumper/;
 
 use JavaScript::V8::Handlebars;
 
-our $VERSION = '0.02';
+our $VERSION = '0.04';
+
+has 'wrapper';
 
 sub register {
 	my( $self, $app, $conf ) = @_;
-
 	my $hbjs = JavaScript::V8::Handlebars->new;
 
+	#TODO Clean this up
+	if( $conf->{wrapper} ) { 
+		for( @{ $app->renderer->paths } ) {
+			if( -r "$_/$conf->{wrapper}" ) {
+				$self->wrapper( "$_/$conf->{wrapper}" );
+				last;
+			}
+		}
+
+		if( $self->wrapper ) {
+			$self->wrapper( $hbjs->compile_file( $self->wrapper ) );
+		}
+		else {
+			die "Failed to find $conf->{wrapper} in @{$app->renderer->paths}";
+		}
+	}
+
+	for( @{ $app->renderer->paths } ) {
+		next unless -d $_;
+		# Magically picks up partials as well
+		$hbjs->add_template_dir( $_ );
+	}
+
+
 	$app->renderer->add_handler( hbs => sub {
 		my( $r, $c, $output, $options ) = @_;
 
+		return unless $r->template_path($options) or length $options->{inline};
 
-		my $template_code = $options->{inline} || slurp $r->template_path($options);
-		die "No template code found" unless length $template_code;
+		if( length $options->{inline} ) {
+			$$output = $hbjs->render_string( $options->{inline}, $c->stash );
+		}
+		elsif( my $template = $r->template_for($c) ) {
+			$$output = $hbjs->execute_template( $template, $c->stash );
+		}
+		else {
+			#TODO should this die?
+			return;
+		}
 
-		#TODO Caching, partials
-		$$output = $hbjs->render_string( $template_code, $c->stash );
+		if( $self->wrapper ) {
+			$$output = $self->wrapper->({ %{$c->stash}, content => $$output });
+		}
 
 		return 1;
 	} );
@@ -44,14 +79,12 @@ This is a plugin for adding the Handlebars templating language to Mojolicious as
 		my $self = shift;
 		...
 
-		$self->plugin('HandlebarsJSRenderer');
+		$self->plugin('HandlebarsJSRenderer', { wrapper => $wrapper });
 		$self->renderer->default_handler('hbs') #default to hbs templates instead of epl
 		...
 	}
 
 
-As of now there are now options available.
-
 
 =head1 AUTHOR
 
